{ hostRegistry, zentralwerk, config, pkgs, lib, ... }:
{
  imports = [
    ./hardware-configuration.nix
    ./tftp.nix
  ];

  networking = {
    hostName = "nix-build"; # Define your hostname.
    useDHCP = false;
    interfaces.enp6s18 = {
      ipv4.addresses = [{
        address = config.c3d2.hosts.nix-build.ip4;
        prefixLength = zentralwerk.lib.config.site.net.serv.subnet4Len;
      }];
      useDHCP = false;
    };
    defaultGateway = "172.20.73.1";
    # TODO: enable firewall
    firewall.enable = false;
    nameservers = [ "172.20.73.8" "9.9.9.9" ];
  };

  boot = {
    loader = {
      systemd-boot.enable = true;
      efi.efiSysMountPoint = "/boot";
    };

    tmpOnTmpfs = true;
    cleanTmpDir = true;

    kernelModules = [ "kvm-intel" ];
    binfmt.emulatedSystems = [ "armv6l-linux" "armv7l-linux" "aarch64-linux" "riscv64-linux" ];
  };

  nix = {
    buildCores = 40;
    maxJobs = 4;
    trustedUsers = [ "client" ];
  };

  services.openssh.permitRootLogin = lib.mkForce "yes";

  system.stateVersion = "20.09"; # Did you read the comment?
}
